# **Developer guide**

Welcome to the **SplitterMR Python API** reference.

![SplitterMR architecture diagram](../assets/splitter_mr_architecture_diagram.svg#gh-light-mode-only)

![SplitterMR architecture diagram](../assets/splitter_mr_architecture_diagram_white.svg#gh-dark-mode-only)

## **Documentation**

### [Model component documentation](./model.md)

Add VLMs (Visual Language Models) to analyze your images from your documents.

### [Reader component documentation](./reader.md)

Use several reading methods to process your files.

### [Splitter component documentation](./splitter.md)

Implement several splitting strategies based on your needs.

### [Embedding component documentation](./embedding.md)

Implement encoder models to perform Semantic Splitting.
